@@ -145,11 +145,15 @@ void emu_set_default_config(void)
 	Config.CdrReschedule = 0;
 	Config.PsxAuto = 1;
 
+	pl_rearmed_cbs.gpu_neon.allow_interlace = 2; // auto
 	pl_rearmed_cbs.gpu_peops.iUseDither = 0;
 	pl_rearmed_cbs.gpu_peops.dwActFixes = 1<<7;
 	pl_rearmed_cbs.gpu_unai.abe_hack =
 	pl_rearmed_cbs.gpu_unai.no_light =
 	pl_rearmed_cbs.gpu_unai.no_blend = 0;
+	memset(&pl_rearmed_cbs.gpu_peopsgl, 0, sizeof(pl_rearmed_cbs.gpu_peopsgl));
+	pl_rearmed_cbs.gpu_peopsgl.iVRamSize = 64;
+	pl_rearmed_cbs.gpu_peopsgl.iTexGarbageCollection = 1;
 
 	iUseReverb = 2;
 	iUseInterpolation = 1;
@@ -249,6 +253,9 @@ void do_emu_action(void)
 	case SACTION_VOLUME_DOWN:
 		plat_step_volume(emu_action == SACTION_VOLUME_UP);
 		return;
+	case SACTION_MINIMIZE:
+		plat_minimize();
+		return;
 	default:
 		return;
 	}
@@ -526,6 +533,9 @@ int emu_save_state(int slot)
 		return ret;
 
 	ret = SaveState(fname);
+#ifndef __ARM_ARCH_7A__ /* XXX */
+	sync();
+#endif
 	printf("* %s \"%s\" [%d]\n", ret == 0 ? "saved" : "failed to save", fname, slot);
 	return ret;
 }
