@@ -157,7 +157,7 @@ enum {
 	PSXINT_GPUOTCDMA,
 	PSXINT_CDRDMA,
 	PSXINT_NEWDRC_CHECK,
-	DUMMY2,
+	PSXINT_RCNT,
 	PSXINT_CDRLID,
 	PSXINT_CDRPLAY,
 	PSXINT_COUNT
@@ -182,6 +182,7 @@ extern u32 event_cycles[PSXINT_COUNT];
 extern u32 next_interupt;
 
 void new_dyna_save(void);
+void new_dyna_after_save(void);
 void new_dyna_restore(void);
 
 #define new_dyna_set_event(e, c) { \
