@@ -57,16 +57,17 @@ window_key_proxy(GtkWidget *widget,
 		     GdkEventKey *event,
 		     gpointer user_data)
 {
-return key_press_event(event->hardware_keycode, event->type == GDK_KEY_PRESS?1:(event->type == GDK_KEY_RELEASE?2:0) );
+	return key_press_event(event->hardware_keycode, event->type == GDK_KEY_PRESS?1:(event->type == GDK_KEY_RELEASE?2:0) );
 }
 
 inline void key_press_event(int key2,int type)
 {
 	int  psxkey1 = -1, psxkey2 = -1;
-int key=keymap[key2];
+	int key=keymap[key2];
 	
-	if (key < 0)
+	if (key < 0){
 		return;
+	}
 
 	if (key < ARRAY_SIZE(keymap2))
 		psxkey1 = keymap2[key];
@@ -158,34 +159,34 @@ void maemo_init(int *argc, char ***argv)
 		sens=150;
 		y_def=500; //near 45 degrees =)
 	}
-if (!(g_maemo_opts&8)){
-	gtk_init (argc, argv);
+	if (!(g_maemo_opts&8)){
+		gtk_init (argc, argv);
 
-	window = hildon_stackable_window_new ();
-	gtk_widget_realize (window);
-	gtk_window_fullscreen (GTK_WINDOW(window));
-	g_signal_connect (G_OBJECT (window), "key-press-event",
-				G_CALLBACK (window_key_proxy), NULL);
-	g_signal_connect (G_OBJECT (window), "key-release-event",
-				G_CALLBACK (window_key_proxy), NULL);
-	g_signal_connect (G_OBJECT (window), "delete_event",
-				G_CALLBACK (hildon_quit), NULL);
-	gtk_widget_add_events (window,
-				GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
+		window = hildon_stackable_window_new ();
+		gtk_widget_realize (window);
+		gtk_window_fullscreen (GTK_WINDOW(window));
+		g_signal_connect (G_OBJECT (window), "key-press-event",
+					G_CALLBACK (window_key_proxy), NULL);
+		g_signal_connect (G_OBJECT (window), "key-release-event",
+					G_CALLBACK (window_key_proxy), NULL);
+		g_signal_connect (G_OBJECT (window), "delete_event",
+					G_CALLBACK (hildon_quit), NULL);
+		gtk_widget_add_events (window,
+					GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 
-	actor = HILDON_ANIMATION_ACTOR (hildon_animation_actor_new());
-	if (g_maemo_opts & 2)
-		hildon_animation_actor_set_position (actor, 0, 0 );
-	else
-		hildon_animation_actor_set_position (actor, (X_RES - D_WIDTH)/2, (Y_RES - D_HEIGHT)/2 );
-	hildon_animation_actor_set_parent (actor, GTK_WINDOW (window));
+		actor = HILDON_ANIMATION_ACTOR (hildon_animation_actor_new());
+		if (g_maemo_opts & 2)
+			hildon_animation_actor_set_position (actor, 0, 0 );
+		else
+			hildon_animation_actor_set_position (actor, (X_RES - D_WIDTH)/2, (Y_RES - D_HEIGHT)/2 );
+		hildon_animation_actor_set_parent (actor, GTK_WINDOW (window));
 
-	drawing = gtk_image_new ();
+		drawing = gtk_image_new ();
 
-	gtk_container_add (GTK_CONTAINER (actor), drawing);
+		gtk_container_add (GTK_CONTAINER (actor), drawing);
 
-	gtk_widget_show_all (GTK_WIDGET (actor));
-	gtk_widget_show_all (GTK_WIDGET (window));
+		gtk_widget_show_all (GTK_WIDGET (actor));
+		gtk_widget_show_all (GTK_WIDGET (window));
 	}
 }
 
@@ -195,7 +196,7 @@ void menu_loop(void)
 
 void *hildon_set_mode(int w, int h)
 {
-if (g_maemo_opts&8) return pl_vout_buf;
+	if (g_maemo_opts&8) return pl_vout_buf;
 
 	if (w <= 0 || h <= 0)
 		return pl_vout_buf;
@@ -224,8 +225,8 @@ if (g_maemo_opts&8) return pl_vout_buf;
 
 void *hildon_flip(void)
 {
-if (!(g_maemo_opts&8))
-	gtk_widget_queue_draw (drawing);
+	if (!(g_maemo_opts&8))
+		gtk_widget_queue_draw (drawing);
 
 	// process accelometer
 	if (g_maemo_opts & 4) {
@@ -246,10 +247,12 @@ if (!(g_maemo_opts&8))
 
 	}
 
-	if (g_maemo_opts&8) maemo_x11_update_keys(); else 
-	/* process GTK+ events */
-	while (gtk_events_pending())
-		gtk_main_iteration();
+	if (g_maemo_opts&8) 
+		maemo_x11_update_keys(); 
+	else 
+		/* process GTK+ events */
+		while (gtk_events_pending())
+			gtk_main_iteration();
 
 	return pl_vout_buf;
 }
@@ -275,3 +278,7 @@ void plat_step_volume(int is_up)
 void plat_trigger_vibrate(void)
 {
 }
+
+void plat_minimize(void)
+{
+}
