@@ -41,8 +41,53 @@ static void ChangeWorkingDirectory(char *exe)
 	}
 }
 
+void PrintHelp()
+{
+	printf("PCSX-ReARMed version %s for Maemo\n\n", PACKAGE_VERSION);
+
+	printf("Usage:\n");
+	printf("  pcsx [options] -cdfile FILE\n\n");
+
+	printf("Options:\n");
+	printf("  -help          : This help\n");
+	printf("  -fullscreen    : Run fullscreen\n");
+	printf("  -frameskip     : Frameskip\n");
+	printf("                   -1=Auto (Default)\n");
+	printf("                    0=Disabled\n");
+	printf("                    1=Set to 1\n");
+	printf("                    ...\n");
+	printf("  -accel         : Enable accelerometer\n");
+	printf("  -sputhreaded   : Use a separate thread for sound\n");
+	printf("  -nosound       : No sound output\n");
+	printf("  -bdir PATH     : Set the bios path\n");
+	printf("  -pdir PATH     : Set the plugins path\n");
+	printf("  -bios          : Set the bios\n");
+	printf("  -cdda          : Disable CD Audio for a performance boost\n");
+	printf("  -xa            : Disables XA sound, which can sometimes\n");
+	printf("                   improve performance\n");
+	printf("  -sio           : SIO IRQ Always Enabled\n");
+	printf("  -spuirq        : SPU IRQ Always Enabled\n");
+	printf("  -fps           : Show fps\n");
+	printf("  -cpu           : Show CPU load\n");
+	printf("  -spu           : Show SPU channels\n");
+	printf("  -nofl          : Disable Frame Limiter\n");
+	printf("  -mcd1 FILE     : Set memory card 1 file\n");
+	printf("  -mcd2 FILE     : Set memory card 2 file\n");
+
+	printf("\nGPU Options:\n");
+	printf("  -gles          : Use the GLES plugin (gpuGLES.so)\n");
+	printf("  -4all          : Use the PCSX4All plugin (gpuPCSX4ALL.so)\n");
+	printf("  -oldgpu        : Use the peops plugin (gpu_peops.so)\n");
+	printf("  -unai          : Use the unai plugin (gpu_unai.so)\n");
+}
+
 int maemo_main(int argc, char **argv)
 {
+	if (argc == 1 || (argc == 2 && (!strcmp(argv[1], "--help") || !strcmp(argv[1], "-help") || !strcmp(argv[1], "-h")))) {
+		PrintHelp();
+		return 0;
+	}
+
 	ChangeWorkingDirectory("c");
 	char file[MAXPATHLEN] = "";
 	char path[MAXPATHLEN];
@@ -50,11 +95,14 @@ int maemo_main(int argc, char **argv)
 	int loadst = 0;
 	int i;
 
+	strcpy(Config.Gpu, "builtin_gpu");
+	strcpy(Config.Spu, "builtin_spu");
 	strcpy(Config.BiosDir, "/home/user/MyDocs");
 	strcpy(Config.PluginsDir, "/opt/maemo/usr/games/plugins");
 	snprintf(Config.PatchesDir, sizeof(Config.PatchesDir), "/opt/maemo/usr/games" PATCHES_DIR);
 	Config.PsxAuto = 1;
-	
+	pl_rearmed_cbs.frameskip = -1;
+
 	// read command line options
 	for (i = 1; i < argc; i++) {
 		     if (!strcmp(argv[i], "-psxout")) Config.PsxOut = 1;
@@ -76,16 +124,20 @@ int maemo_main(int argc, char **argv)
 		}
 		else if (!strcmp(argv[i],"-frameskip")) {
 			int tv_reg = atol(argv[++i]);
-			if (tv_reg > 0)
+			if (tv_reg < -1)
 				pl_rearmed_cbs.frameskip = -1;
+			else
+				pl_rearmed_cbs.frameskip = tv_reg;
 		}
-		else if (!strcmp(argv[i],"-fullscreen"))		g_maemo_opts |= 2;
-		else if (!strcmp(argv[i],"-accel"))				g_maemo_opts |= 4;
-		else if (!strcmp(argv[i],"-sputhreaded"))		iUseTimer=1;
-		else if (!strcmp(argv[i],"-nosound"))		strcpy(Config.Spu, "spunull.so");
+		else if (!strcmp(argv[i], "-fullscreen"))		g_maemo_opts |= 2;
+		else if (!strcmp(argv[i], "-accel"))				g_maemo_opts |= 4;
+		else if (!strcmp(argv[i], "-sputhreaded"))		iUseTimer=1;
+		else if (!strcmp(argv[i], "-nosound"))		strcpy(Config.Spu, "spunull.so");
 		else if (!strcmp(argv[i], "-bdir"))			sprintf(Config.BiosDir, "%s", argv[++i]);
+		else if (!strcmp(argv[i], "-pdir"))			sprintf(Config.PluginsDir, "%s", argv[++i]);
 		else if (!strcmp(argv[i], "-bios"))			sprintf(Config.Bios, "%s", argv[++i]);
 		else if (!strcmp(argv[i], "-gles"))			{strcpy(Config.Gpu, "gpuGLES.so");g_maemo_opts |=8 ;}
+		else if (!strcmp(argv[i], "-4all"))			strcpy(Config.Gpu, "gpuPCSX4ALL.so");
 		else if (!strcmp(argv[i], "-oldgpu"))		strcpy(Config.Gpu, "gpu_peops.so");
 		else if (!strcmp(argv[i], "-unai"))		strcpy(Config.Gpu, "gpu_unai.so");
 		else if (!strcmp(argv[i], "-cdda"))		Config.Cdda = 1;
@@ -96,7 +148,10 @@ int maemo_main(int argc, char **argv)
 		else if (!strcmp(argv[i], "-vsync"))	Config.VSyncWA = 1;
 		else if (!strcmp(argv[i], "-fps")) 		g_opts |=OPT_SHOWFPS;
 		else if (!strcmp(argv[i], "-cpu")) 		g_opts |=OPT_SHOWCPU;
+		else if (!strcmp(argv[i], "-spu")) 		g_opts |=OPT_SHOWSPU;
 		else if (!strcmp(argv[i], "-nofl")) 		g_opts |=OPT_NO_FRAMELIM;
+		else if (!strcmp(argv[i], "-mcd1")) 	sprintf(Config.Mcd1, "%s", argv[++i]);
+		else if (!strcmp(argv[i], "-mcd2")) 	sprintf(Config.Mcd2, "%s", argv[++i]);
 	}
 
 	hildon_init(&argc, &argv);
@@ -149,7 +204,6 @@ int maemo_main(int argc, char **argv)
 		printf("%s state %d\n", ret ? "failed to load" : "loaded", loadst);
 	}
 
-
 	maemo_init(&argc, &argv);
 
 	if (GPU_open != NULL) {
@@ -157,7 +211,7 @@ int maemo_main(int argc, char **argv)
 		if (ret){
 			fprintf(stderr, "Warning: GPU_open returned %d\n", ret);
 			gpuDisp=ret;
-			}
+		}
 	}
 
 	dfinput_activate();
