@@ -27,4 +27,4 @@ extern void pl_update_gun(int *xn, int *xres, int *y, int *in);
 
 /* vibration trigger to frontend */
 extern int in_enable_vibration;
-extern void plat_trigger_vibrate(void);
+extern void plat_trigger_vibrate(int is_strong);
