@@ -27,25 +27,8 @@
 //#include "gpuStdafx.h"
 
 //#include <mmsystem.h>
-
 #define _IN_GPU
 
-#ifdef _WINDOWS
-#include "stdafx.h"
-#include <stdlib.h>
-#include <stdio.h>
-#include <stdarg.h>
-#include <string.h>
-#include <mmsystem.h>
-
-#include "externals.h"
-#include "gpu.h"
-#include "draw.h"
-#include "prim.h"
-#include "texture.h"
-#include "fps.h"
-#include "resource.h"
-#else
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -60,10 +43,7 @@
 //#include "NoPic.h"
 
 #include "gpuStdafx.h"
-#endif
 
-extern void ProcessEvents();
-               
 short g_m1=255,g_m2=255,g_m3=255;
 short DrawSemiTrans=FALSE;
 short Ymin;
@@ -83,8 +63,8 @@ int           iTileCheat=0;
 // memory image of the PSX vram
 ////////////////////////////////////////////////////////////////////////
 
-u8  *psxVSecure;
-u8  *psxVub;
+unsigned char  *psxVSecure;
+unsigned char  *psxVub;
 signed   char  *psxVsb;
 unsigned short *psxVuw;
 unsigned short *psxVuw_eom;
@@ -100,10 +80,6 @@ BOOL            bNeedInterlaceUpdate=FALSE;
 BOOL            bNeedRGB24Update=FALSE;
 BOOL            bChangeWinMode=FALSE;
 
-#ifdef _WINDOWS
-extern HGLRC    GLCONTEXT;
-#endif
-
 unsigned long   ulStatusControl[256];
 
 ////////////////////////////////////////////////////////////////////////
@@ -112,10 +88,10 @@ unsigned long   ulStatusControl[256];
 
 static long     GPUdataRet;
 long            lGPUstatusRet;
-s8            szDispBuf[64];
+char            szDispBuf[64];
 
 static unsigned long gpuDataM[256];
-static u8 gpuCommand = 0;
+static unsigned char gpuCommand = 0;
 static long          gpuDataC = 0;
 static long          gpuDataP = 0;
 
@@ -144,7 +120,7 @@ BOOL            bDisplayNotSet = TRUE;
 GLuint          uiScanLine=0;
 int             iUseScanLines=0;
 long            lSelectedSlot=0;
-u8 * pGfxCardScreen=0;
+unsigned char * pGfxCardScreen=0;
 int             iBlurBuffer=0;
 int             iScanBlend=0;
 int             iRenderFVR=0;
@@ -155,28 +131,12 @@ int             iRumbleVal    = 0;
 int             iRumbleTime   = 0;
 
 static void (*rearmed_get_layer_pos)(int *x, int *y, int *w, int *h);
+static void flipEGL(void);
 
 ////////////////////////////////////////////////////////////////////////
 // stuff to make this a true PDK module
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
-s8 * CALLBACK PSEgetLibName(void)
-{
- return "name";
-}
-
-unsigned long CALLBACK PSEgetLibType(void)
-{
- return  1;
-}
-
-unsigned long CALLBACK PSEgetLibVersion(void)
-{
- return 1<<16|1<<8|1;
-}
-#endif
-
 ////////////////////////////////////////////////////////////////////////
 // snapshot funcs (saves screen to bitmap / text infos into file)
 ////////////////////////////////////////////////////////////////////////
@@ -189,10 +149,10 @@ void ResizeWindow()
  glViewport(rRatioRect.left,                           // init viewport by ratio rect
             iResY-(rRatioRect.top+rRatioRect.bottom),
             rRatioRect.right, 
-            rRatioRect.bottom);         
+            rRatioRect.bottom); glError();
                                                       
- glScissor(0, 0, iResX, iResY);                        // init clipping (fullscreen)
- glEnable(GL_SCISSOR_TEST);                       
+ glScissor(0, 0, iResX, iResY); glError();             // init clipping (fullscreen)
+ glEnable(GL_SCISSOR_TEST); glError();
 
 #ifndef OWNSCALE
  glMatrixMode(GL_TEXTURE);                             // init psx tex sow and tow if not "ownscale"
@@ -200,22 +160,19 @@ void ResizeWindow()
  glScalef(1.0f/255.99f,1.0f/255.99f,1.0f);             // geforce precision hack
 #endif 
 
- glMatrixMode(GL_PROJECTION);                          // init projection with psx resolution
- glLoadIdentity();
+ glMatrixMode(GL_PROJECTION); glError();               // init projection with psx resolution
+ glLoadIdentity(); glError();
  glOrtho(0,PSXDisplay.DisplayMode.x,
-         PSXDisplay.DisplayMode.y, 0, -1, 1);
+         PSXDisplay.DisplayMode.y, 0, -1, 1); glError();
  if (bKeepRatio)
  SetAspectRatio();
 }
 
-s8 * GetConfigInfos(int hW)
+char * GetConfigInfos(int hW)
 {
-#ifdef _WINDOWS
- HDC hdc;HGLRC hglrc;
-#endif
- s8 szO[2][4]={"off","on "};
- s8 szTxt[256];
- s8 * pB=(s8 *)malloc(32767);
+ char szO[2][4]={"off","on "};
+ char szTxt[256];
+ char * pB=(char *)malloc(32767);
 /*
  if(!pB) return NULL;
  *pB=0;
@@ -237,7 +194,7 @@ s8 * GetConfigInfos(int hW)
  strcat(pB,szTxt);
  sprintf(szTxt,"OGL version: %s\r\n\r\n",(char *)glGetString(GL_VERSION));
  strcat(pB,szTxt);
- //strcat(pB,(s8 *)glGetString(GL_EXTENSIONS));
+ //strcat(pB,(char *)glGetString(GL_EXTENSIONS));
  //strcat(pB,"\r\n\r\n");
 
 #ifdef _WINDOWS
@@ -395,11 +352,7 @@ void DoSnapShot(void)
 {
 }       
 
-#ifdef _WINDOWS
 void CALLBACK GPUmakeSnapshot(void)
-#else
-void CALLBACK GPUmakeSnapshot(void)
-#endif
 {
  //bSnapShot = TRUE;
 }        
@@ -408,31 +361,17 @@ void CALLBACK GPUmakeSnapshot(void)
 // GPU INIT... here starts it all (first func called by emu)
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 long CALLBACK GPUinit()
-#else
-long CALLBACK GPUinit()
-#endif
 {
 memset(ulStatusControl,0,256*sizeof(unsigned long));
 
-#ifdef _WINDOWS
-iResX=240;iResY=320;
-#endif
 bChangeRes=FALSE;
-#ifdef _WINDOWS
-bWindowMode=TRUE;
-#else
 bWindowMode=FALSE;
-#endif 
-#ifdef _WINDOWS
-iWinSize=MAKELONG(iResX,iResY);
-#endif
 
 bKeepRatio = TRUE;
 // different ways of accessing PSX VRAM
 
-psxVSecure=(u8 *)malloc((iGPUHeight*2)*1024 + (1024*1024)); // always alloc one extra MB for soft drawing funcs security
+psxVSecure=(unsigned char *)malloc((iGPUHeight*2)*1024 + (1024*1024)); // always alloc one extra MB for soft drawing funcs security
 if(!psxVSecure) return -1;
 
 psxVub=psxVSecure+512*1024;                           // security offset into double sized psx vram!
@@ -500,33 +439,6 @@ return 0;
 }                             
 
 
-////////////////////////////////////////////////////////////////////////
-// GPU OPEN: funcs to open up the gpu display (Windows)
-////////////////////////////////////////////////////////////////////////
-
-#ifdef _WINDOWS
-
-void ChangeDesktop()                                   // change destop resolution
-{
- DEVMODE dv;long lRes,iTry=0;                       
-
- while(iTry<10)                                        // keep on hammering...
-  {
-   memset(&dv,0,sizeof(DEVMODE));
-   dv.dmSize=sizeof(DEVMODE);
-   dv.dmBitsPerPel=iColDepth;
-   dv.dmPelsWidth=iResX;
-   dv.dmPelsHeight=iResY;
-
-   dv.dmFields=DM_BITSPERPEL|DM_PELSWIDTH|DM_PELSHEIGHT;
-
-   lRes=ChangeDisplaySettings(&dv,0);                  // ...hammering the anvil
-
-   if(lRes==DISP_CHANGE_SUCCESSFUL) return;
-   iTry++;Sleep(10);
-  }
-}
-
 ////////////////////////////////////////////////////////////////////////
 // OPEN interface func: attention! 
 // some emus are calling this func in their main Window thread,
@@ -541,35 +453,12 @@ void ChangeDesktop()                                   // change destop resoluti
 // some PAD or SPU plugins would not work anymore)
 ////////////////////////////////////////////////////////////////////////
 
-HMENU hPSEMenu=NULL;
-
-long CALLBACK GPUopen(HWND hwndGPU)                    
-#else
 long CALLBACK GPUopen(int hwndGPU)
-#endif
 {
-	#ifdef _WINDOWS
-	HDC hdc;RECT r;DEVMODE dv;
-
-	 hWWindow = hwndGPU;                                   // store hwnd globally
-	#endif
-	// InitKeyHandler();                                     // init key handler (subclass window)
-
-
-
-	#ifdef _WINDOWS
-	 iResX=240;iResY=320;
-	#endif
-#ifdef MAEMO_CHANGES
-	  iResX=800;iResY=480;
-#endif
+	 iResX=800;iResY=480;
 	 iColDepth=8;
 	 bChangeRes=FALSE;
-	#ifdef _WINDOWS
-	 bWindowMode=TRUE;
-	#else
 	 bWindowMode=FALSE;
-	#endif 
 	 bFullVRam=FALSE;
 	 iFilterType=0;
 	// bAdvancedBlend=FALSE;
@@ -583,9 +472,6 @@ long CALLBACK GPUopen(int hwndGPU)
 	 //bOpaquePass=FALSE;
 	 //bUseAntiAlias=FALSE;
 	 //iTexQuality=0;
-	#ifdef _WINDOWS
-	 iWinSize=MAKELONG(iResX,iResY);
-	#endif
 	 iUseMask=0;
 	 iZBufferDepth=0;
 	 bUseFastMdec=FALSE;
@@ -607,65 +493,12 @@ long CALLBACK GPUopen(int hwndGPU)
 
 
 
-#ifdef _WINDOWS
- memset(&dv,0,sizeof(DEVMODE));
- dv.dmSize=sizeof(DEVMODE);
- EnumDisplaySettings(NULL,ENUM_CURRENT_SETTINGS,&dv);
-#endif
  bIsFirstFrame = TRUE;                                 // flag: we have to init OGL later in windows!
 
-#ifdef _WINDOWS
- if(bWindowMode)                                       // win mode?
-  {
-   DWORD dw=GetWindowLong(hWWindow, GWL_STYLE);        // -> adjust wnd style (owndc needed by some stupid ogl drivers)
-   dw&=~WS_THICKFRAME;
-   dw|=WS_BORDER|WS_CAPTION|CS_OWNDC;
-   SetWindowLong(hWWindow, GWL_STYLE, dw);
-
-   hPSEMenu=GetMenu(hWWindow);                         // -> hide emu menu (if any)
-   if(hPSEMenu!=NULL) SetMenu(hWWindow,NULL);
-
-   iResX=LOWORD(iWinSize);iResY=HIWORD(iWinSize);
-   ShowWindow(hWWindow,SW_SHOWNORMAL);
-
-   MoveWindow(hWWindow,                                // -> center wnd
-      GetSystemMetrics(SM_CXFULLSCREEN)/2-iResX/2,
-      GetSystemMetrics(SM_CYFULLSCREEN)/2-iResY/2,
-      iResX+GetSystemMetrics(SM_CXFIXEDFRAME)+3,
-      iResY+GetSystemMetrics(SM_CYFIXEDFRAME)+GetSystemMetrics(SM_CYCAPTION)+3,
-      TRUE);
-   UpdateWindow(hWWindow);                             // -> let windows do some update
-
-   if(dv.dmBitsPerPel==16 || dv.dmBitsPerPel==32)      // -> overwrite user color info with desktop color info
-    iColDepth=dv.dmBitsPerPel;
-  }
- else                                                  // fullscreen mode:
-  {
-   if(dv.dmBitsPerPel!=(unsigned int)iColDepth ||      // -> check, if we have to change resolution
-      dv.dmPelsWidth !=(unsigned int)iResX ||
-      dv.dmPelsHeight!=(unsigned int)iResY)
-    bChangeRes=TRUE; else bChangeRes=FALSE;
-
-   if(bChangeRes) ChangeDesktop();                     // -> change the res (had to do an own func because of some MS 'optimizations')
-
-   SetWindowLong(hWWindow, GWL_STYLE, CS_OWNDC);       // -> adjust wnd style as well (to be sure)
-                
-   hPSEMenu=GetMenu(hWWindow);                         // -> hide menu
-   if(hPSEMenu!=NULL) SetMenu(hWWindow,NULL);
-   ShowWindow(hWWindow,SW_SHOWMAXIMIZED);              // -> max mode
-  }
-#endif
  rRatioRect.left   = rRatioRect.top=0;
  rRatioRect.right  = iResX;
  rRatioRect.bottom = iResY;
 
-#ifdef _WINDOWS
- r.left=r.top=0;r.right=iResX;r.bottom=iResY;          // hack for getting a clean black window until OGL gets initialized
- hdc = GetDC(hWWindow);
- FillRect(hdc,&r,(HBRUSH)GetStockObject(BLACK_BRUSH));
- bSetupPixelFormat(hdc);
- ReleaseDC(hWWindow,hdc);
-#endif
  bDisplayNotSet = TRUE; 
  bSetClip=TRUE;
 
@@ -673,43 +506,21 @@ long CALLBACK GPUopen(int hwndGPU)
 
  InitializeTextureStore();                             // init texture mem
 
-// lGPUstatusRet = 0x74000000;
+ CSTEXTURE = CSVERTEX = CSCOLOR = 0;
 
-// with some emus, we could do the OGL init right here... oh my
- //if(bIsFirstFrame)
- GLinitialize();
+ // lGPUstatusRet = 0x74000000;
 
-extern Display*                x11Display ;
+ // with some emus, we could do the OGL init right here... oh my
+ if(bIsFirstFrame) GLinitialize();
 
- return x11Display;
+  extern Display*                x11Display ;	
+  return x11Display;
 }
 
 ////////////////////////////////////////////////////////////////////////
 // close
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
-long CALLBACK GPUclose()                               // WINDOWS CLOSE
-{
-// ExitKeyHandler();
-
- GLcleanup();                                          // close OGL
-
- if(bChangeRes)                                        // change res back
-  ChangeDisplaySettings(NULL,0);
-
- if(hPSEMenu)                                          // set menu again
-  SetMenu(hWWindow,hPSEMenu);
-
- if(pGfxCardScreen) free(pGfxCardScreen);              // free helper memory
- pGfxCardScreen=0;
-
-// if(iNoScreenSaver) EnableScreenSaver(TRUE);           // enable screen saver again
-
- return 0;
-}
-
-#else
 
 long GPUclose()                                        // LINUX CLOSE
 {
@@ -722,17 +533,12 @@ long GPUclose()                                        // LINUX CLOSE
 
  return 0;
 }
-#endif
 
 ////////////////////////////////////////////////////////////////////////
 // I shot the sheriff... last function called from emu 
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 long CALLBACK GPUshutdown()
-#else
-long CALLBACK GPUshutdown()
-#endif
 {
  if(psxVSecure) free(psxVSecure);                      // kill emulated vram memory
  psxVSecure=0;
@@ -747,15 +553,15 @@ long CALLBACK GPUshutdown()
 void PaintBlackBorders(void)
 {
  short s;
+ glDisable(GL_SCISSOR_TEST); glError();
+ if(bTexEnabled) {glDisable(GL_TEXTURE_2D);bTexEnabled=FALSE;} glError();
+ if(bOldSmoothShaded) {glShadeModel(GL_FLAT);bOldSmoothShaded=FALSE;} glError();
+ if(bBlendEnable)     {glDisable(GL_BLEND);bBlendEnable=FALSE;} glError();
+ glDisable(GL_ALPHA_TEST); glError();
 
- glDisable(GL_SCISSOR_TEST);
- if(bTexEnabled) {glDisable(GL_TEXTURE_2D);bTexEnabled=FALSE;}
- if(bOldSmoothShaded) {glShadeModel(GL_FLAT);bOldSmoothShaded=FALSE;}
- if(bBlendEnable)     {glDisable(GL_BLEND);bBlendEnable=FALSE;}
- glDisable(GL_ALPHA_TEST);
+ glEnable(GL_ALPHA_TEST); glError();
+ glEnable(GL_SCISSOR_TEST); glError();
 
- glEnable(GL_ALPHA_TEST);
- glEnable(GL_SCISSOR_TEST);
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -796,10 +602,6 @@ void updateDisplay(void)                               // UPDATE DISPLAY
 {
 BOOL bBlur=FALSE;
 
-#ifdef _WINDOWS
-HDC hdc=GetDC(hWWindow);                              // windows:
-wglMakeCurrent(hdc,GLCONTEXT);                        // -> make context current again
-#endif
 
 bFakeFrontBuffer=FALSE;
 bRenderFrontBuffer=FALSE;
@@ -841,11 +643,13 @@ if(PreviousPSXDisplay.Range.x0||                      // paint black borders aro
 
 if(PSXDisplay.Disabled)                               // display disabled?
  {
+  //LOGE("PSXDisplay.Disabled");
+
   // moved here
-  glDisable(GL_SCISSOR_TEST);                       
-  glClearColor(0,0,0,128);                            // -> clear whole backbuffer
-  glClear(uiBufferBits);
-  glEnable(GL_SCISSOR_TEST);                       
+  glDisable(GL_SCISSOR_TEST); glError();                       
+  glClearColor(0,0,0,128); glError();                 // -> clear whole backbuffer
+  glClear(uiBufferBits); glError();
+  glEnable(GL_SCISSOR_TEST); glError();                       
   gl_z=0.0f;
   bDisplayNotSet = TRUE;
  }
@@ -887,29 +691,16 @@ if(bUseFrameSkip)                                     // frame skipping active ?
  {
   if(!bSkipNextFrame) 
    {
-    if(iDrawnSomething)
-#ifdef _WINDOWS
-     SwapBuffers(wglGetCurrentDC());                  // -> to skip or not to skip
-#else
-     eglSwapBuffers(display,surface);
-#endif
+    if(iDrawnSomething)     flipEGL();
    }
-  if(dwActFixes&0x180)                                // -> special old frame skipping: skip max one in a row
-   {
     if((fps_skip < fFrameRateHz) && !(bSkipNextFrame)) 
      {bSkipNextFrame = TRUE; fps_skip=fFrameRateHz;}
     else bSkipNextFrame = FALSE;
-   }
-  else FrameSkip();
+
  }
 else                                                  // no skip ?
  {
-  if(iDrawnSomething)
-#ifdef _WINDOWS
-   SwapBuffers(wglGetCurrentDC());                    // -> swap
-#else
-  eglSwapBuffers(display,surface);
-#endif
+  if(iDrawnSomething)  flipEGL();
  }
 
 iDrawnSomething=0;
@@ -926,11 +717,10 @@ if(lClearOnSwap)                                      // clear buffer after swap
   g=((GLclampf)GREEN(lClearOnSwapColor))/255.0f;      // -> get col
   b=((GLclampf)BLUE(lClearOnSwapColor))/255.0f;
   r=((GLclampf)RED(lClearOnSwapColor))/255.0f;
-  
-  glDisable(GL_SCISSOR_TEST);                       
-  glClearColor(r,g,b,128);                            // -> clear 
-  glClear(uiBufferBits);
-  glEnable(GL_SCISSOR_TEST);                       
+  glDisable(GL_SCISSOR_TEST); glError();                       
+  glClearColor(r,g,b,128); glError();                 // -> clear 
+  glClear(uiBufferBits); glError();
+  glEnable(GL_SCISSOR_TEST); glError();                       
   lClearOnSwap=0;                                     // -> done
  }
 else 
@@ -939,11 +729,12 @@ else
 
   if(iZBufferDepth)                                   // clear zbuffer as well (if activated)
    {
-    glDisable(GL_SCISSOR_TEST);                       
-    glClear(GL_DEPTH_BUFFER_BIT);
-    glEnable(GL_SCISSOR_TEST);                       
+    glDisable(GL_SCISSOR_TEST); glError();
+    glClear(GL_DEPTH_BUFFER_BIT); glError();
+    glEnable(GL_SCISSOR_TEST); glError();
    }
  }
+
 gl_z=0.0f;
 
 //----------------------------------------------------//
@@ -990,7 +781,7 @@ if(iRumbleTime)                                       // shake screen by modifyi
   glViewport(rRatioRect.left+i1,                      
              iResY-(rRatioRect.top+rRatioRect.bottom)+i2,
              rRatioRect.right+i3, 
-             rRatioRect.bottom+i4);            
+             rRatioRect.bottom+i4); glError();
  }
 
 //----------------------------------------------------//
@@ -1023,18 +814,9 @@ bRenderFrontBuffer=FALSE;
 // if(gTexPicName) DisplayPic();
 // if(ulKeybits&KEY_SHOWFPS) DisplayText();
 
-#ifdef _WINDOWS
- {                                                    // windows: 
-  HDC hdc=GetDC(hWWindow);
-  wglMakeCurrent(hdc,GLCONTEXT);                      // -> make current again
-  if(iDrawnSomething)
-   SwapBuffers(wglGetCurrentDC());                    // -> swap
-  ReleaseDC(hWWindow,hdc);                            // -> ! important !
- }
-#else
 if(iDrawnSomething)                                   // linux:
- eglSwapBuffers(display,surface);
-#endif
+      flipEGL();
+
 
 //if(iBlurBuffer) UnBlurBackBuffer();
 }
@@ -1138,12 +920,11 @@ if(r.bottom < 1)     r.bottom = 1;
 
 r.left = (iResX-r.right)/2;
 r.top  = (iResY-r.bottom)/2;
-
 if(r.bottom<rRatioRect.bottom ||
    r.right <rRatioRect.right)
  {
   RECT rC;
-  glClearColor(0,0,0,128);                         
+  glClearColor(0,0,0,128); glError();
 
   if(r.right <rRatioRect.right)
    {
@@ -1151,11 +932,12 @@ if(r.bottom<rRatioRect.bottom ||
     rC.top=0;
     rC.right=r.left;
     rC.bottom=iResY;
-    glScissor(rC.left,rC.top,rC.right,rC.bottom);
-    glClear(uiBufferBits);
+    glScissor(rC.left,rC.top,rC.right,rC.bottom); glError();
+    glClear(uiBufferBits); glError();
     rC.left=iResX-rC.right;
-    glScissor(rC.left,rC.top,rC.right,rC.bottom);
-    glClear(uiBufferBits);
+    glScissor(rC.left,rC.top,rC.right,rC.bottom); glError();
+    
+    glClear(uiBufferBits); glError();
    }
 
   if(r.bottom <rRatioRect.bottom)
@@ -1164,11 +946,12 @@ if(r.bottom<rRatioRect.bottom ||
     rC.top=0;
     rC.right=iResX;
     rC.bottom=r.top;
-    glScissor(rC.left,rC.top,rC.right,rC.bottom);
-    glClear(uiBufferBits);
+    glScissor(rC.left,rC.top,rC.right,rC.bottom); glError();
+
+    glClear(uiBufferBits); glError();
     rC.top=iResY-rC.bottom;
-    glScissor(rC.left,rC.top,rC.right,rC.bottom);
-    glClear(uiBufferBits);
+    glScissor(rC.left,rC.top,rC.right,rC.bottom); glError();
+    glClear(uiBufferBits); glError();
    }
   
   bSetClip=TRUE;
@@ -1185,7 +968,7 @@ rRatioRect=r;
 glViewport(rRatioRect.left,
            iResY-(rRatioRect.top+rRatioRect.bottom),
            rRatioRect.right,
-           rRatioRect.bottom);                         // init viewport
+           rRatioRect.bottom); glError();              // init viewport
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -1205,9 +988,9 @@ if ((PSXDisplay.DisplayMode.y == PSXDisplay.DisplayModeNew.y) &&
  }
 else                                                  // some res change?
  {
-  glLoadIdentity();
+  glLoadIdentity(); glError();
   glOrtho(0,PSXDisplay.DisplayModeNew.x,              // -> new psx resolution
-            PSXDisplay.DisplayModeNew.y, 0, -1, 1);
+            PSXDisplay.DisplayModeNew.y, 0, -1, 1); glError();
   if(bKeepRatio) SetAspectRatio();
  }
 
@@ -1246,15 +1029,6 @@ if(bUp) updateDisplay();                              // yeah, real update (swap
 // window mode <-> fullscreen mode (windows)
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
-void ChangeWindowMode(void)
-{
- GPUclose();
- bWindowMode=!bWindowMode;
- GPUopen(hWWindow);
- bChangeWinMode=FALSE;
-}
-#endif
 
 ////////////////////////////////////////////////////////////////////////
 // swap update check (called by psx vsync function)
@@ -1322,11 +1096,7 @@ return FALSE;
 
 static unsigned short usFirstPos=2;
 
-#ifdef _WINDOWS
 void CALLBACK GPUupdateLace(void)
-#else
-void CALLBACK GPUupdateLace(void)
-#endif
 {
 if(!(dwActFixes&0x1000))                               
  STATUSREG^=0x80000000;                               // interlaced bit toggle, if the CC game fix is not active (see gpuReadStatus)
@@ -1355,20 +1125,13 @@ else if(usFirstPos==1)                                // initial updates (after
   updateDisplay();
  }
 
-#ifdef _WINDOWS
-if(bChangeWinMode) ChangeWindowMode();
-#endif
 }
 
 ////////////////////////////////////////////////////////////////////////
 // process read request from GPU status register
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 unsigned long CALLBACK GPUreadStatus(void)
-#else
-unsigned long CALLBACK GPUreadStatus(void)
-#endif
 {
 if(dwActFixes&0x1000)                                 // CC game fix
  {
@@ -1404,17 +1167,11 @@ return STATUSREG;
 // these are always single packet commands.
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 void CALLBACK GPUwriteStatus(unsigned long gdata)
-#else
-void CALLBACK GPUwriteStatus(unsigned long gdata)
-#endif
 {
 unsigned long lCommand=(gdata>>24)&0xff;
 
-#ifdef _WINDOWS
 if(bIsFirstFrame) GLinitialize();                     // real ogl startup (needed by some emus)
-#endif
 
 ulStatusControl[lCommand]=gdata;
 
@@ -1733,8 +1490,8 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
  int ux,uy,udx,udy,wx,wy;
  unsigned short * p1, *p2;
  float XS,YS;
- u8 * ps;
- u8 * px;
+ unsigned char * ps;
+ unsigned char * px;
  unsigned short s,sx;
 
  if(STATUSREG&GPUSTATUS_RGB24) return;
@@ -1830,16 +1587,15 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
 
  if(!pGfxCardScreen)
   {
-   glPixelStorei(GL_PACK_ALIGNMENT,1);
-   pGfxCardScreen=(u8 *)malloc(iResX*iResY*4);
+   glPixelStorei(GL_PACK_ALIGNMENT,1); glError();
+   pGfxCardScreen=(unsigned char *)malloc(iResX*iResY*4);
   }
 
  ps=pGfxCardScreen;
  
  //if(!sArea) glReadBuffer(GL_FRONT);
 
- glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps);
-               
+ glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps); glError();
  //if(!sArea) glReadBuffer(GL_BACK);
 
  s=0;
@@ -1884,7 +1640,7 @@ void CheckVRamRead(int x, int y, int dx, int dy, bool bFront)
 {
  unsigned short sArea;unsigned short * p;
  int ux,uy,udx,udy,wx,wy;float XS,YS;
- u8 * ps, * px;
+ unsigned char * ps, * px;
  unsigned short s=0,sx;
 
  if(STATUSREG&GPUSTATUS_RGB24) return;
@@ -1978,16 +1734,15 @@ void CheckVRamRead(int x, int y, int dx, int dy, bool bFront)
 
  if(!pGfxCardScreen)
   {
-   glPixelStorei(GL_PACK_ALIGNMENT,1);
-   pGfxCardScreen=(u8 *)malloc(iResX*iResY*4);
+   glPixelStorei(GL_PACK_ALIGNMENT,1); glError();
+   pGfxCardScreen=(unsigned char *)malloc(iResX*iResY*4);
   }
 
  ps=pGfxCardScreen;
  
 // if(bFront) glReadBuffer(GL_FRONT);
 
- glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps);
-               
+ glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps); glError(); glError();
 // if(bFront) glReadBuffer(GL_BACK);
 
  XS=(float)dx/(float)(udx);
@@ -2020,11 +1775,7 @@ void CheckVRamRead(int x, int y, int dx, int dy, bool bFront)
 // core read from vram
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
-void CALLBACK GPUreadDataMem(unsigned int * pMem, int iSize)
-#else
 void CALLBACK GPUreadDataMem(unsigned long * pMem, int iSize)
-#endif
 {
 int i;
 
@@ -2096,18 +1847,10 @@ ENDREAD:
 GPUIsIdle;
 }
 
-#ifdef _WINDOWS
 unsigned long CALLBACK GPUreadData(void)
-#else
-unsigned long CALLBACK GPUreadData(void)
-#endif
 {
  unsigned long l;
-#ifdef _WINDOWS
  GPUreadDataMem(&l,1);
-#else
- GPUreadDataMem(&l,1);
-#endif 
  return GPUdataRet;
 }
 
@@ -2115,7 +1858,7 @@ unsigned long CALLBACK GPUreadData(void)
 // helper table to know how much data is used by drawing commands
 ////////////////////////////////////////////////////////////////////////
 
-const u8 primTableCX[256] =
+const unsigned char primTableCX[256] =
 {
     // 00
     0,0,3,0,0,0,0,0,
@@ -2189,13 +1932,9 @@ const u8 primTableCX[256] =
 // processes data send to GPU data register
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 void CALLBACK GPUwriteDataMem(unsigned long * pMem, int iSize)
-#else
-void CALLBACK GPUwriteDataMem(unsigned long * pMem, int iSize)
-#endif
 {
-u8 command;
+unsigned char command;
 unsigned long gdata=0;
 int i=0;
 GPUIsBusy;
@@ -2255,7 +1994,7 @@ ENDVRAM:
 
 if(iDataWriteMode==DR_NORMAL)
  {
-  void (* *primFunc)(u8 *);
+  void (* *primFunc)(unsigned char *);
   if(bSkipNextFrame) primFunc=primTableSkip;
   else               primFunc=primTableJ;
 
@@ -2267,7 +2006,7 @@ if(iDataWriteMode==DR_NORMAL)
 
     if(gpuDataC == 0)
      {
-      command = (u8)((gdata>>24) & 0xff);
+      command = (unsigned char)((gdata>>24) & 0xff);
 
       if(primTableCX[command])
        {
@@ -2296,7 +2035,7 @@ if(iDataWriteMode==DR_NORMAL)
     if(gpuDataP == gpuDataC)
      {
       gpuDataC=gpuDataP=0;
-      primFunc[gpuCommand]((u8 *)gpuDataM);
+      primFunc[gpuCommand]((unsigned char *)gpuDataM);
 
       if(dwEmuFixes&0x0001 || dwActFixes&0x20000)     // hack for emulating "gpu busy" in some games
        iFakePrimBusy=4;
@@ -2312,17 +2051,9 @@ GPUIsIdle;
 
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 void CALLBACK GPUwriteData(unsigned long gdata)
-#else
-void CALLBACK GPUwriteData(unsigned long gdata)
-#endif
 {
-#ifdef _WINDOWS
  GPUwriteDataMem(&gdata,1);
-#else
- GPUwriteDataMem(&gdata,1);
-#endif 
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -2360,9 +2091,9 @@ return iT;
 
 /*#include <unistd.h>
 
-void StartCfgTool(s8 * pCmdLine)                     // linux: start external cfg tool
+void StartCfgTool(char * pCmdLine)                     // linux: start external cfg tool
 {
- FILE * cf;s8 filename[255],t[255];
+ FILE * cf;char filename[255],t[255];
 
  strcpy(filename,"cfg/cfgPeopsMesaGL");                 // look in cfg sub folder first
  cf=fopen(filename,"rb");
@@ -2406,22 +2137,9 @@ void StartCfgTool(s8 * pCmdLine)                     // linux: start external cf
 #endif
 
 
-#ifdef _WINDOWS
 long CALLBACK GPUconfigure(void)
-#else
-long CALLBACK GPUconfigure(void)
-#endif
 {
 
-#ifdef _WINDOWS
-// HWND hWP=GetActiveWindow();
-// DialogBox(hInst,MAKEINTRESOURCE(IDD_CFGDLG),
-//           hWP,(DLGPROC)CfgDlgProc);
-#else
-
-// StartCfgTool("CFG");
-
-#endif
 
  return 0;
 }
@@ -2460,14 +2178,10 @@ return FALSE;
 // core gives a dma chain to gpu: same as the gpuwrite interface funcs
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 long CALLBACK GPUdmaChain(unsigned long * baseAddrL, unsigned long addr)
-#else
-long CALLBACK GPUdmaChain(unsigned long * baseAddrL, unsigned long addr)
-#endif
 {
 unsigned long dmaMem;
-u8 * baseAddrB;
+unsigned char * baseAddrB;
 short count;unsigned int DMACommandCounter = 0;
 
 if(bIsFirstFrame) GLinitialize();
@@ -2476,7 +2190,7 @@ GPUIsBusy;
 
 lUsedAddr[0]=lUsedAddr[1]=lUsedAddr[2]=0xffffff;
 
-baseAddrB = (u8*) baseAddrL;
+baseAddrB = (unsigned char*) baseAddrL;
 
 do
  {
@@ -2489,11 +2203,7 @@ do
 
   dmaMem=addr+4;
 
-#ifdef _WINDOWS
   if(count>0) GPUwriteDataMem(&baseAddrL[dmaMem>>2],count);
-#else
-  if(count>0) GPUwriteDataMem(&baseAddrL[dmaMem>>2],count);
-#endif
   
   addr = baseAddrL[addr>>2]&0xffffff;
  }
@@ -2508,11 +2218,7 @@ return 0;
 // show about dlg
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 void CALLBACK GPUabout(void)
-#else
-void CALLBACK GPUabout(void)
-#endif
 {
 
 }
@@ -2521,11 +2227,7 @@ void CALLBACK GPUabout(void)
 // We are ever fine ;)
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 long CALLBACK GPUtest(void)
-#else
-long CALLBACK GPUtest(void)
-#endif
 {
  // if test fails this function should return negative value for error (unable to continue)
  // and positive value for warning (can continue but output might be crappy)
@@ -2539,11 +2241,7 @@ long CALLBACK GPUtest(void)
 
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
 long CALLBACK GPUfreeze(unsigned long ulGetFreezeData,GPUFreeze_t * pF)
-#else
-long CALLBACK GPUfreeze(unsigned long ulGetFreezeData,GPUFreeze_t * pF)
-#endif
 {
 if(ulGetFreezeData==2) 
  {
@@ -2574,7 +2272,6 @@ memcpy(psxVub,         pF->psxVRam,  1024*iGPUHeight*2);
 
 ResetTextureArea(TRUE);
 
-#ifdef _WINDOWS
  GPUwriteStatus(ulStatusControl[0]);
  GPUwriteStatus(ulStatusControl[1]);
  GPUwriteStatus(ulStatusControl[2]);
@@ -2584,17 +2281,6 @@ ResetTextureArea(TRUE);
  GPUwriteStatus(ulStatusControl[7]);
  GPUwriteStatus(ulStatusControl[5]);
  GPUwriteStatus(ulStatusControl[4]);
-#else
- GPUwriteStatus(ulStatusControl[0]);
- GPUwriteStatus(ulStatusControl[1]);
- GPUwriteStatus(ulStatusControl[2]);
- GPUwriteStatus(ulStatusControl[3]);
- GPUwriteStatus(ulStatusControl[8]);
- GPUwriteStatus(ulStatusControl[6]);
- GPUwriteStatus(ulStatusControl[7]);
- GPUwriteStatus(ulStatusControl[5]);
- GPUwriteStatus(ulStatusControl[4]);
-#endif
  return 1;
 }
 
@@ -2607,7 +2293,7 @@ ResetTextureArea(TRUE);
 //10 = red
 //11 = transparent
 
-u8 cFont[10][120]=
+unsigned char cFont[10][120]=
 {
 // 0
 {0xaa,0xaa,0xaa,0xaa,0xaa,0xaa,
@@ -2833,7 +2519,7 @@ u8 cFont[10][120]=
 
 ////////////////////////////////////////////////////////////////////////
 
-void PaintPicDot(u8 * p,u8 c)
+void PaintPicDot(unsigned char * p,unsigned char c)
 {
  if(c==0) {*p++=0x00;*p++=0x00;*p=0x00;return;}
  if(c==1) {*p++=0xff;*p++=0xff;*p=0xff;return;}
@@ -2842,27 +2528,23 @@ void PaintPicDot(u8 * p,u8 c)
 
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
-void CALLBACK GPUgetScreenPic(u8 * pMem)
-#else
-long CALLBACK GPUgetScreenPic(u8 * pMem)
-#endif
+long CALLBACK GPUgetScreenPic(unsigned char * pMem)
 {
  float XS,YS;int x,y,v;
- u8 * ps, * px, * pf;
- u8 c;
+ unsigned char * ps, * px, * pf;
+ unsigned char c;
 
  if(!pGfxCardScreen)
   {
-   glPixelStorei(GL_PACK_ALIGNMENT,1);
-   pGfxCardScreen=(u8 *)malloc(iResX*iResY*4);
+   glPixelStorei(GL_PACK_ALIGNMENT,1); glError();
+   pGfxCardScreen=(unsigned char *)malloc(iResX*iResY*4);
   }
 
  ps=pGfxCardScreen;
 
 // glReadBuffer(GL_FRONT);
 
- glReadPixels(0,0,iResX,iResY,GL_RGB,GL_UNSIGNED_BYTE,ps);
+ glReadPixels(0,0,iResX,iResY,GL_RGB,GL_UNSIGNED_BYTE,ps); glError();
                
 // glReadBuffer(GL_BACK);
 
@@ -2894,13 +2576,13 @@ long CALLBACK GPUgetScreenPic(u8 * pMem)
     {
      c=cFont[lSelectedSlot][x+y*6];
      v=(c&0xc0)>>6;
-     PaintPicDot(pf,(u8)v);pf+=3;                // paint the dots into the rect
+     PaintPicDot(pf,(unsigned char)v);pf+=3;                // paint the dots into the rect
      v=(c&0x30)>>4;
-     PaintPicDot(pf,(u8)v);pf+=3;
+     PaintPicDot(pf,(unsigned char)v);pf+=3;
      v=(c&0x0c)>>2;
-     PaintPicDot(pf,(u8)v);pf+=3;
+     PaintPicDot(pf,(unsigned char)v);pf+=3;
      v=c&0x03;
-     PaintPicDot(pf,(u8)v);pf+=3;
+     PaintPicDot(pf,(unsigned char)v);pf+=3;
     }
    pf+=104*3;
   }
@@ -2925,11 +2607,7 @@ long CALLBACK GPUgetScreenPic(u8 * pMem)
 
 ////////////////////////////////////////////////////////////////////////
 
-#ifdef _WINDOWS
-void CALLBACK GPUshowScreenPic(u8 * pMem)
-#else
-long CALLBACK GPUshowScreenPic(u8 * pMem)
-#endif
+long CALLBACK GPUshowScreenPic(unsigned char * pMem)
 {
 // DestroyPic();
 // if(pMem==0) return;
@@ -2976,3 +2654,7 @@ void CALLBACK GPUrearmedCallbacks(const void **cbs)
  rearmed_get_layer_pos = cbs[0];
 }
 
+static void flipEGL(void)
+{
+ eglSwapBuffers(display, surface);
+}
